#   Google Spreadsheet Reports for OpenERP
#   Copyright 2010 Canonical Ltd.
#
#   This program is free software: you can redistribute it and/or modify it 
#   under the terms of the GNU Affero Public License version 3, as published 
#   by the Free Software Foundation.
#
#   This program is distributed in the hope that it will be useful, but 
#   WITHOUT ANY WARRANTY; without even the implied warranties of 
#   MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
#   PURPOSE.  See the GNU Affero Public License for more details.
#
#   You should have received a copy of the GNU Affero Public License along 
#   with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import unittest

from connection import Connection
from connection import DocConnection
from connection import SpreadsheetConnection
from connection import DatabaseConnection
from ConfigParser import SafeConfigParser


class TestConnection(unittest.TestCase):
    def setUp(self):
        # Read the config file
        config = SafeConfigParser()
        config.read("google.conf")
        self.email = config.get("Google", "email")
        self.pwd = config.get("Google", "password")
        self.spreadsheet = config.get("Google", "spreadsheet")
        self.worksheet = config.get("Google", "worksheet")

        # Initialise the connections to Google docs
        self.connection = Connection(self.email, self.pwd)
        self.dbconnect = DatabaseConnection(self.email, self.pwd)
        
    def test00Connect(self):
        self.assertNotEqual(self.connection.email , None)
        self.assertEqual(self.connection.email , self.email)

    def test01CreateDb(self):
        db = self.dbconnect.create_database(self.spreadsheet)
        self.assertNotEqual(db , None)
    
        # Create the table
        fields = ["user","project","task","date","weekstart","hours"]
        table = self.dbconnect.create_table(db, self.worksheet, fields)
        self.assertNotEqual(table, None)

    def test02GetDocs(self):
        self.docconnect = DocConnection(self.email, self.pwd)
        docs = self.docconnect.get_docs()
        self.assertEqual(type(docs), type([]))

    def test03Spreadsheet(self):
        self.sheetconnect = SpreadsheetConnection(self.email, self.pwd)
        self.assertNotEqual(self.sheetconnect.client, None)

        sheet = self.sheetconnect.get_document_id(self.spreadsheet)
        self.assertNotEqual(sheet, None)

        worksheets = self.sheetconnect.get_worksheets(sheet)
        self.assertNotEqual(worksheets, None)
        self.assertEqual(type(worksheets), type([]))
        
        work_id = self.sheetconnect.get_worksheet_id(sheet, self.worksheet)
        self.assertEqual(type(work_id), type(""))

        # Insert data row
        row = {"project":"Project", "task":"1", "hours":"5.0", "date":"2010-09-02", "weekstart":"2010-08-30"}
        res = self.sheetconnect.insert_row(sheet, work_id, row)
        self.assertNotEqual(res, None)

    def test04Database(self):
        self.assertNotEqual(self.dbconnect.client, None)

    def test05DbTables(self):
        # Get the databases
        dbs = self.dbconnect.get_databases(self.spreadsheet)
        self.assertNotEqual(dbs, None)
        
        # Get tables for the database i.e. worksheets
        tables = self.dbconnect.get_tables(dbs[0], self.worksheet)
        self.assertNotEqual(tables, None)

        # Get the first row in the table
        row = self.dbconnect.get_row(tables[0], 1)
        self.assertNotEqual(row, None)

        # Get multiple rows
        rows = self.dbconnect.get_rows(tables[0], 1,999)
        self.assertNotEqual(rows, None)
    
        # Check the truncate table functionality
        self.dbconnect.truncate_table(tables[0])
        rows = self.dbconnect.get_rows(tables[0], 1,999)
        self.assertEqual(len(rows),0)
        

    def test06DbRecords(self):
        # Get the database and tables
        dbs = self.dbconnect.get_databases(self.spreadsheet)
        tables = self.dbconnect.get_tables(dbs[0], self.worksheet)

        # Add a row
        row = {"user":"John Smith","project":"Project", "task":"1", "hours":"5.0", "date":"2010-09-02" }
        rec = self.dbconnect.add_record(tables[0], row)
        self.assertNotEqual(rec, None)
        self.assertEqual(rec.content, row)



if __name__ == '__main__':
    unittest.main()

        
        
