#   Google Spreadsheet Reports for OpenERP
#   Copyright 2010 Canonical Ltd.
#
#   This program is free software: you can redistribute it and/or modify it 
#   under the terms of the GNU Affero Public License version 3, as published 
#   by the Free Software Foundation.
#
#   This program is distributed in the hope that it will be useful, but 
#   WITHOUT ANY WARRANTY; without even the implied warranties of 
#   MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
#   PURPOSE.  See the GNU Affero Public License for more details.
#
#   You should have received a copy of the GNU Affero Public License along 
#   with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import time, datetime

from osv import fields,osv,orm
from tools.translate import _

class report_example(osv.osv):
    """
    An example report that shows how to create a Google Spreadsheet report from
    a Python method. This uses a custom model object with a method that returns
    a list of lists.
    """
    _name = 'report.gdata.example'
    _description = 'Google Spreadsheet Python Report Example'

    def run_report(self, cr, uid, *args):
        """
        The 'function' that is called by the Google Spreadsheet report record.
        The method can be named whatever you want.
        This example returns a list of partners.
        """
        # Get the IDs of the partners
        partner_obj = self.pool.get('res.partner')
        ids = partner_obj.search(cr, uid, [])

        # Initialise the 'list of lists' that will be return
        rows = []

        # Create a set of column headers (not strictly necessary)
        rows.append(['Name', 'ID','City','Phone'])

        for p in partner_obj.browse(cr, uid, ids):
            # Initialise a new (spreadsheet) row
            row = []
            
            # Add the relevant 'cells' to the row
            row.append(p.name)
            row.append(p.id)
            row.append(p.city)
            row.append(p.phone)

            # Append this row to the list of rows
            rows.append(row)

        # Return the list of rows for output to the Google Spreadsheet
        return rows

report_example()

